# ldc-gitingest
llm-dataset-converter extension that integrates the [gitingest](https://github.com/cyclotruc/gitingest) library.


## Installation

```bash
pip install git+https://github.com/waikato-llm/llm-dataset-converter.git
pip install git+https://github.com/waikato-llm/ldc-gitingest.git
```

## Plugins

See [here](plugins/README.md) for an overview of all plugins.
